const showLog = false;
function log() {
    showLog && console.log.apply(console, arguments);
}

// Open the survey page when they uninstall.
chrome.runtime.onInstalled.addListener(details => {
    const manifest = chrome.runtime.getManifest();
    const queryArgs = [
        `app=${encodeURIComponent(manifest.appNameCode)}`,
        `updateTime=${encodeURIComponent(unixTimestamp())}`,
        `vh=${encodeURIComponent([manifest.version].join(','))}`
    ];
    const url = 'http://rehfeld.us/browser-extensions/uninstall-survey.php?' + queryArgs.join('&');
    chrome.runtime.setUninstallURL(url);
});

// Open the setup / install / configuration instructions page when they install.
chrome.runtime.onInstalled.addListener(function (details) {
    if (details.reason === chrome.runtime.OnInstalledReason.INSTALL) {
        const url = chrome.runtime.getURL('ext-web/setup.html');
        // const url = 'http://rehfeld.us/browser-extensions/hide-incognito-mode/setup.html';
        chrome.tabs.create({url: url}, function (tab) {
            log(`New tab launched for ${url}`);
        });
    }
});

// Clear their browsing data when they click the action icon, but only if the tab is incognito.
chrome.browserAction.onClicked.addListener(function(tab) {
    // This runs in background page.
    // This callback can get called without activeTab, but w/o that it cant access the tab.url nor other stuff.
    if (tab.incognito) {
        clearBrowsingData(function removeSuccessCallback() {
            chrome.tabs.executeScript({
                file: 'show-private-data-cleared-message.js'
            });
        });
    }
});

function unixTimestamp() {
    return Math.floor(Date.now() / 1000);
}

function clearBrowsingData(removeSuccessCallback) {

    const millisecondsPerWeek = 1000 * 60 * 60 * 24 * 7;
    const oneWeekAgo = (new Date()).getTime() - millisecondsPerWeek;
    const removalOptions = {
        "since": 0,
        "originTypes": {
            "protectedWeb": true
        }
    };

    const dataTypeSet = {
        "appcache": true,
        "cache": true,
        "cacheStorage": true,
        "cookies": true,
        "downloads": true,
        "fileSystems": true,
        "formData": true,
        "history": true,
        "indexedDB": true,
        "localStorage": true,
        "serverBoundCertificates": true,
        "pluginData": true,
        "passwords": true,
        "serviceWorkers": true,
        "webSQL": true
    };

    chrome.browsingData.remove(removalOptions, dataTypeSet, removeSuccessCallback);
}


